﻿/**
 * 统计功能对象
 */
var elementSphere = null;
var StatisticsMgr = {
    projectList: null,
    /**
     * 功能：初始化项目列表
     * 参数：container-显示项目列表的jquery容器对象;
     * 返回：无
     */
    initProjectList: function(container) {
        this.projectList = [];
        var rootLayerList = earth.LayerManager.LayerList;
        var projectCount = rootLayerList.GetChildCount();
        for (var i = 0; i < projectCount; i++) {
            var childLayer = rootLayerList.GetChildAt(i);
            var layerType = childLayer.LayerType;
            if (layerType === "Project") {
                var projectId = childLayer.Guid;
                var projectName = childLayer.Name;
                var pipeList = this.getPipeListByLayer(childLayer);
                if (pipeList.length > 0) {
                    this.projectList.push({
                        projectId: projectId,
                        projectName: projectName,
                        pipeList: pipeList
                    });
                    //container.append('<option value="' + projectId + '">' + projectName + '</option>');
                }
            }
        }
    },
    /**
     * 功能：获取指定图层下的所有管线图层列表
     * 参数：layer-指定图层
     * 返回：指定图层下的所有管线图层列表
     */
    getPipeListByLayer: function(layer) {
        if (layer == null) return;
        var pipelineArr = [];
        var count = layer.GetChildCount();
        for (var i = 0; i < count; i++) {
            var childLayer = layer.GetChildAt(i);
            var layerTypeC = childLayer.LayerType;
            if (layerTypeC === "Pipeline") {
                var pipelineId = childLayer.Guid;
                var pipelineName = childLayer.Name;
                var pipelineServer = childLayer.GISServer;
                var layerType = childLayer.PipeLineType;
                pipelineArr.push({
                    id: pipelineId,
                    name: pipelineName,
                    server: pipelineServer,
                    LayerType: layerType
                });
            } else {
                var childCount = childLayer.GetChildCount();
                if (childCount > 0) {
                    var childPipelineArr = this.getPipeListByLayer(childLayer);
                    for (var k = 0; k < childPipelineArr.length; k++) {
                        pipelineArr.push(childPipelineArr[k]);
                    }
                }
            }
        }
        return pipelineArr;
    },
    sphereGotoLookat: function(key, subLayer, layerID, pointKey, bShow, originCoord, htmlStr) {
        var deep = 0; //管点埋深
        var pointHeight = 0; //管线半径&高度;
        var US_SPT_KEY = top.getName("US_SPT_KEY", 1, true);
        var filterStartKey = "(and,eq," + US_SPT_KEY + "," + pointKey + ")";

        var US_EPT_KEY = parent.getName("US_EPT_KEY", 1, true);
        var filterEndKey = "(and,eq," + US_EPT_KEY + "," + pointKey + ")";

        var lineResult = this.paramQuery(null, layerID, filterStartKey, 16, 1);
        var lintGotoPage = lineResult.GotoPage(0);
        if (lintGotoPage == "error") { //用终点key再次查询
            lineResult = this.paramQuery(null, layerID, filterEndKey, 16, 1);
            lintGotoPage = lineResult.GotoPage(0);
        }
        if (lintGotoPage != "error") {
            var lineJson = $.xml2json(lintGotoPage);
            var lineRecords = lineJson.Result.Record;
            if (typeof(lineRecords) == "object") {
                var lineStartKey = lineRecords[top.getName("US_SPT_KEY", 1, true)];
                var lineEndKey = lineRecords[top.getName("US_EPT_KEY", 1, true)];
                var startDeep = lineRecords[top.getName("US_SDEEP", 1, true)];
                var endDeep = lineRecords[top.getName("US_EDEEP", 1, true)];
                if (lineStartKey == pointKey) {
                    deep = startDeep;
                } else if (lineEndKey == pointKey) {
                    deep = endDeep;
                }
            } else if (lineRecords instanceof Array) {
                for (var l = 0; l < lineRecords.length; l++) {
                    var red = lineRecords[l];
                    var startDeep = red[top.getName("US_SDEEP", 1, true)];
                    var endDeep = red[top.getName("US_EDEEP", 1, true)];
                    if (startDeep == pointKey) {
                        deep = startDeep;
                        break;
                    } else if (endDeep == pointKey) {
                        deep = endDeep;
                        break;
                    }
                }
            }
        }

        var uskey = top.getName("US_KEY", 0, true);
        var strPara = "";

        strPara += "(or,equal," + uskey + "," + pointKey + ")";

        var param = subLayer.QueryParameter;
        param.Filter = strPara;
        param.QueryType = 17; // SE_AttributeData
        param.QueryTableType = 0;// 0：SE_Table_Point，1：SE_Table_Line
        var result = subLayer.SearchFromGISServer();
        var PointResult = result.GotoPage(0);
        var object = result.GetLocalObject(0);
        var json = $.xml2json(PointResult);
        var records = json.Result.Record;
        if (records) {
            var pointShape = records.SHAPE.Point.Coordinates;
            var x = null;
            var y = null;
            for (var i = 0; i < pointShape.split(",").length; i += 3) {
                x = pointShape.split(",")[i];
                y = pointShape.split(",")[i + 1];
            }
            var layer = earth.LayerManager.GetLayerByGUID(layerID);
            var intLayerCode = layer.PipeLineType;

            earth.Event.OnGetAltitudeFinished = function(geopoint) {
                if (geopoint) {
                    var h = geopoint.Altitude;
                    pointHeight = (parseFloat(pointHeight) / 1000) / 2; //半径
                    // var z = Number(h) - Number(pointHeight) - Number(deep);
                    var z = Number(h) - Number(pointHeight)
                    if (intLayerCode >= 4000 && intLayerCode < 5000) {
                        // z = Number(h) - Number(deep) + Number(pointHeight); //排水
                        z = Number(h) - Number(deep)
                    }
                    if (bShow) {
                        top.showHtmlBalloon(x, y, z, htmlStr);
                    }
                    StatisticsMgr.createElementSphere(x, y, z); //创建球
                    earth.GlobeObserver.GotoLookat(x, y, z, 0.0, 89.0, 0, 6);
                }
            }
            earth.GlobeObserver.GetAltitudeFromNet(x, y);
        }
    },
    /**
     * 功能：将table导出成Excel文档
     * 参数：tableId - 要导出的表对象; columns - 列标题数组
     * 返回：无
     */
    importExcelByTable: function(tabObj, columns) {
        var xls = null;
        try {
            xls = new ActiveXObject("Excel.Application");
        } catch (e) {
            alert("无法启动Excel\n\n如果您确信您的电脑中已经安装了Excel, 那么请调整IE的安全级别\n" +
                "具体的操作：\n" +
                "工具 -> Internet选项 -> 安全 -> 自定义级别 -> 对没有标记为安全的ActiveX进行初始化和脚本运行 -> 启用");
            return;
        }
        try {
            xls.visible = true;
            var xlsBook = xls.Workbooks.Add;
            var xlsSheet = xlsBook.WorkSheets(1);

            for (var k = 0; k < columns.length; k++) {
                xlsSheet.Cells(1, k + 1).Value = columns[k];
            }

            var rowList = tabObj.rows;
            for (var i = 0; i < rowList.length; i++) {
                var cellList = rowList[i].cells;
                for (var j = 0; j < cellList.length; j++) {
                    xlsSheet.Cells(i + 2, j + 1).Value = cellList[j].innerHTML;
                }
            }
            xls.UserControl = true;
        } catch (err) {
            alert("出现一个异常:" + err.message);
        }
    },
    /**
     * 功能：初始化管线图层列表
     * 参数：projectId-指定项目的id编号; container-显示管线图层列表的jquery容器对象; callback-管线初始化完成之后的回调函数
     * 返回：无
     */
    initPipelinePointLineList: function(projectId, container, callback) {
        container.html("");

        var pipelineList = null;
        if (this.projectList == null) {
            this.initProjectList();
        }
        for (var k = 0; k < this.projectList.length; k++) {
            if (this.projectList[k].projectId === projectId) {
                pipelineList = this.projectList[k].pipeList;
                break;
            }
        }
        if (pipelineList == null) {
            return;
        }

        for (var i = 0; i < pipelineList.length; i++) {
            var pipeLineLayer = pipelineList[i];
            container.append('<option value="' +
                pipeLineLayer.id + '" server="' + pipeLineLayer.server + '" title="' + pipeLineLayer.name + '">' +
                pipeLineLayer.name + '线</option>');
            container.append('<option value="' +
                pipeLineLayer.id + '" server="' + pipeLineLayer.server + '" title="' + pipeLineLayer.name + '">' +
                pipeLineLayer.name + '点</option>');
        }

        if (callback != null) {
            callback();
        }
    },
    detachShere: function() {
        if (elementSphere != null) {
            earth.DetachObject(elementSphere);
            elementSphere = null;
        }
    },
    paramQuery: function(pFeat, guid, filter, queryType, queryTableType) {
        var layer = earth.LayerManager.GetLayerByGUID(guid);
        var subLayer = null;
        for (var i = 0, len = layer.GetChildCount(); i < len; i++) {
            subLayer = layer.GetChildAt(i);
            if (subLayer.LayerType == "Container") { // 使用具体的_container图层
                break;
            }
        }
        if (subLayer == null) {
            return;
        }
        var param = subLayer.QueryParameter;
        param.ClearSpatialFilter();
        if (filter != null) {
            param.Filter = filter;
        }
        if (pFeat != null) {
            param.SetSpatialFilter(pFeat);
        }
        if (queryTableType != null) {
            param.QueryTableType = queryTableType; // 0：SE_Table_Point，1：SE_Table_Line
        }
        param.QueryType = queryType; // SE_AttributeData
        param.PageRecordCount = 12;
        var result = subLayer.SearchFromGISServer();
        return result;
    },
    createElementSphere: function(x, y, h) {
        var radius = 0.3;
        h = h - parseFloat(radius);
        if (elementSphere != null) {
            earth.DetachObject(elementSphere);
            elementSphere = null;
        }
        //获取工厂对象
        var factory = earth.Factory;
        //创建GUID
        var sphereGuid = factory.CreateGUID();
        //创建模型对象
        elementSphere = factory.CreateElementSphere(sphereGuid, "sphere");
        elementSphere.BeginUpdate();
        var lon = x;
        var lat = y;
        var alt = h;
        elementSphere.SphericalTransform.SetLocationEx(lon, lat, alt);
        elementSphere.FillColor = parseInt("0x77ff0000");
        elementSphere.Radius = radius;
        elementSphere.Underground = true;
        elementSphere.EndUpdate();
        earth.ShapeCreator.Clear();
        earth.AttachObject(elementSphere);
        elementSphere.ShowHighLight();
    },
};
